close all

% load variables
load abbvars
% define input sequence
u = [
    0        2   0   1  1.56 0  ;
    100      2   0   1  1.56 1  ; % simulate fault at 100 sec
    200      2   0   1  1.56 1  ;    
]

% simulate to generate a sample trajectory
[tt,xx,yy]=sim('openloop',[0 215]);
figure(1);
plot(t,y); xlabel('Time(s)'); ylabel('Voltages ');

% find intervals for the state variables
x1min = min(xx(:,1));  x1max = max(xx(:,1)); 
x2min = min(xx(:,2));  x2max = max(xx(:,2)); 
x1rang=(x1max-x1min);
x2rang=(x2max-x2min);

% plot without  fault
N=15;
x1v = (x1min-x1rang/10):(x1max-x1min)/N:(x1max+x1rang/10);
x2v = (x2min-x2rang/10):(x2max-x2min)/N:(x2max+x2rang/10);

ut = [2 0 1 1.56 0]'; 
[xdot,y]=calcsurf(x1v,x2v,ut);

% with fault
ut = [2 0 1 1.56 1]'; 
[xdot2,y2]=calcsurf(x1v,x2v,ut);


subplot(221)
mesh(x1v,x2v,y(:,:,3));
title('Voltage at Bus 4 with and w/o fault, TrStep=1');
xlabel('xp'),ylabel('xq'),zlabel('V4');
hold on 
mesh(x1v,x2v,y2(:,:,3));
axis([min(x1v)*1.2 max(x1v)*1.2 min(x2v)*1.2 max(x2v)*1.2 0.6 1.1])
view(120,30)

subplot(222)
mesh(x1v,x2v,xdot(:,:,1));
hold on
mesh(x1v,x2v,xdot2(:,:,1));
title('der(xp) with and w/o fault, TrStep=1');
xlabel('xp'),ylabel('xq'),zlabel('der(xp)');
view(120,30)
axis([min(x1v)*1.2 max(x1v)*1.2 min(x2v)*1.2 max(x2v)*1.2 -0.3 0.3])

% now with off nominal tap (at -4)
% plot without  fault
ut = [2 0 -4 1.56 0]'; 
[xdot,y]=calcsurf(x1v,x2v,ut);
% with fault
ut = [2 0 -4 1.56 1]'; 
[xdot2,y2]=calcsurf(x1v,x2v,ut);
subplot(223)
mesh(x1v,x2v,y(:,:,3));
title('Voltage at Bus 4 with and w/o fault, TrStep=-4');
xlabel('xp'),ylabel('xq'),zlabel('V4');
axis([min(x1v)*1.2 max(x1v)*1.2 min(x2v)*1.2 max(x2v)*1.2 0.6 1.1])
view(120,30)


hold on 
mesh(x1v,x2v,y2(:,:,3));
subplot(224)
mesh(x1v,x2v,xdot(:,:,1));
hold on
mesh(x1v,x2v,xdot2(:,:,1));
title('der(xp) with and w/o fault, TrStep=-4');
xlabel('xp'),ylabel('xq'),zlabel('der(xp)');
view(120,30)
axis([min(x1v)*1.2 max(x1v)*1.2 min(x2v)*1.2 max(x2v)*1.2 -0.3 0.3])



